from django.apps import AppConfig
from django.utils.translation import gettext_lazy


class PluginApp(AppConfig):
    name = "swarm_pretalx"
    verbose_name = "Pretalx plugin for exporting the agenda to Swarm"

    class PretalxPluginMeta:
        name = gettext_lazy("Pretalx plugin for exporting the agenda to Swarm")
        author = "cmdctrlesc"
        description = gettext_lazy("Pretalx plugin for exporting the agenda to Swarm")
        visible = True
        version = "0.0.0"

    def ready(self):
        from . import signals  # NOQA




import logging

from django.conf import settings
from django.dispatch import receiver
from pretalx.agenda.tasks import export_schedule_html
from pretalx.schedule.signals import schedule_release
from .tasks import post_to_swarm

logger = logging.getLogger("Swarm-plugin-logger")

def get_export_zip_path(event):
    export_path = settings.HTMLEXPORT_ROOT / event.slug
    return export_path.with_suffix(".zip")


@receiver(schedule_release, dispatch_uid="swarm signal")
def on_schedule_release(sender, schedule, user, **kwargs):

    zip_path = str(get_export_zip_path(sender))

    try:
        export_schedule_html.apply_async(kwargs={"event_id": sender.id}, link=post_to_swarm.si(zip_path))
    except Exception as e:
        logger.info(e)    





import base64
import json
import logging
import os
from pathlib import Path

import requests
from pretalx.celery_app import app

dotenv_path = Path(__file__).parent

logger = logging.getLogger("Swarm-plugin-logger")

try:
    load_dotenv()
except Exception as e:
    logger.warning(
        "Problems loading .env file. Please check the structure and location of the file! See README for more."
    )

GITHUB_TOKEN = os.getenv("GITHUB_TOKEN")
GITHUB_USERNAME = os.getenv("GITHUB_USERNAME")
GITHUB_EMAIL = os.getenv("GITHUB_EMAIL")

repo = "datafund/web_devconagenda"
filename = "democon.zip"
url = "https://api.github.com/repos/{}/contents/{}".format(repo, filename)
token = "Bearer {}".format(GITHUB_TOKEN)
headers = {"Accept": "application/vnd.github+json", "Authorization": token}


@app.task
def post_to_swarm(zip_path):
    try:

        resp2 = requests.get(url, headers=headers)
        sha = json.loads(resp2.text)["sha"]

        with open(zip_path, "rb") as f:
            file = f.read()

        encoded = base64.b64encode(file)
        data = {
            "message": "upload agenda zip",
            "committer": {"name": GITHUB_USERNAME, "email": GITHUB_EMAIL},
            "content": encoded.decode(),
            "sha": sha,
            "branch": "main",
        }
        resp3 = requests.put(url, headers=headers, data=json.dumps(data))
        logger.info("Agenda succesfully exported to Swarm!")

    except Exception as e:
        logger.warning(str(e))




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['swarm_pretalx']

package_data = \
{'': ['*'],
 'swarm_pretalx': ['locale/de_DE/LC_MESSAGES/*',
                   'locale/fr_FR/LC_MESSAGES/*',
                   'static/swarm_pretalx/*',
                   'templates/swarm_pretalx/*']}

install_requires = \
['python-dotenv>=0.21.0,<0.22.0']

setup_kwargs = {
    'name': 'swarm-pretalx',
    'version': '0.1.4',
    'description': 'A Pretalx plugin that exports the agenda on Swarm',
    'long_description': None,
    'author': 'cmdctrlesc',
    'author_email': 'alanxyz210@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
